==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/OperationFilterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterExpressionDescriptionMetadata } from "./FilterExpressionDescriptionMetadata";
import { OperationFilterExpressionDescription } from "./OperationFilterExpressionDescription";
/**
 * @hidden
 */
var OperationFilterExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(OperationFilterExpressionDescriptionMetadata, _super);
    function OperationFilterExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OperationFilterExpressionDescriptionMetadata.b = function (a) {
        if (OperationFilterExpressionDescriptionMetadata.a == null) {
            OperationFilterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            OperationFilterExpressionDescriptionMetadata.c(OperationFilterExpressionDescriptionMetadata.a);
        }
        if (a.j(OperationFilterExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(OperationFilterExpressionDescriptionMetadata.a);
        FilterExpressionDescriptionMetadata.d(a);
    };
    OperationFilterExpressionDescriptionMetadata.c = function (a) {
        FilterExpressionDescriptionMetadata.c(a);
        a.item("PropertyName", "String");
        a.item("ValueRef", "(w:Value,wf:Value)DataRef");
        a.item("Left", "ExportedType:IFilterExpression");
        a.item("Right", "ExportedType:IFilterExpression");
        a.item("Operator", "ExportedType:string:FilterExpressionOperatorType");
        a.item("Operator@names", "None;Equal;NotEqual;GreaterThan;GreaterThanOrEqual;LessThan;LessThanOrEqual;And;Or;Not;Add;Subtract;Multiply;Divide;Modulo;Grouping");
    };
    OperationFilterExpressionDescriptionMetadata.d = function (a) {
        OperationFilterExpressionDescriptionMetadata.b(a);
        a.aa("OperationFilterExpression", function () { return new OperationFilterExpressionDescription(); });
        a.z("OperationFilterExpression", OperationFilterExpressionDescriptionMetadata.a);
    };
    OperationFilterExpressionDescriptionMetadata.$t = markType(OperationFilterExpressionDescriptionMetadata, 'OperationFilterExpressionDescriptionMetadata');
    OperationFilterExpressionDescriptionMetadata.a = null;
    return OperationFilterExpressionDescriptionMetadata;
}(Base));
export { OperationFilterExpressionDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/OperationFilterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterExpressionDescriptionMetadata } from "./FilterExpressionDescriptionMetadata";
import { OperationFilterExpressionDescription } from "./OperationFilterExpressionDescription";
/**
 * @hidden
 */
var OperationFilterExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(OperationFilterExpressionDescriptionMetadata, _super);
    function OperationFilterExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OperationFilterExpressionDescriptionMetadata.b = function (a) {
        if (OperationFilterExpressionDescriptionMetadata.a == null) {
            OperationFilterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            OperationFilterExpressionDescriptionMetadata.c(OperationFilterExpressionDescriptionMetadata.a);
        }
        if (a.k(OperationFilterExpressionDescriptionMetadata.a)) {
            return;
        }
        a.aa(OperationFilterExpressionDescriptionMetadata.a);
        FilterExpressionDescriptionMetadata.d(a);
    };
    OperationFilterExpressionDescriptionMetadata.c = function (a) {
        FilterExpressionDescriptionMetadata.c(a);
        a.item("PropertyName", "String");
        a.item("ValueRef", "(w:Value,wf:Value)DataRef");
        a.item("Left", "ExportedType:IFilterExpression");
        a.item("Right", "ExportedType:IFilterExpression");
        a.item("Operator", "ExportedType:string:FilterExpressionOperatorType");
        a.item("Operator@names", "None;Equal;NotEqual;GreaterThan;GreaterThanOrEqual;LessThan;LessThanOrEqual;And;Or;Not;Add;Subtract;Multiply;Divide;Modulo;Grouping");
    };
    OperationFilterExpressionDescriptionMetadata.d = function (a) {
        OperationFilterExpressionDescriptionMetadata.b(a);
        a.ac("OperationFilterExpression", function () { return new OperationFilterExpressionDescription(); });
        a.ab("OperationFilterExpression", OperationFilterExpressionDescriptionMetadata.a);
    };
    OperationFilterExpressionDescriptionMetadata.$t = markType(OperationFilterExpressionDescriptionMetadata, 'OperationFilterExpressionDescriptionMetadata');
    OperationFilterExpressionDescriptionMetadata.a = null;
    return OperationFilterExpressionDescriptionMetadata;
}(Base));
export { OperationFilterExpressionDescriptionMetadata };
